==> openshift-enterprise-console-container-v4.1.16-201909100604.tar.gz: openshift-enterprise-console-container-v4.1.16-201909100604/frontend/public/components/utils/request-size-input.tsx <==
/* eslint-disable no-undef, no-unused-vars */
import * as React from 'react';
import { Dropdown } from '.';

export class RequestSizeInput extends React.Component<RequestSizeInputProps> {
  state = {
    unit: this.props.defaultRequestSizeUnit,
    value: this.props.defaultRequestSizeValue,
  }

  onValueChange: React.ReactEventHandler<HTMLInputElement> = event => {
    this.setState({ value: event.currentTarget.value });
    this.props.onChange({ value: event.currentTarget.value, unit: this.state.unit });
  };

  onUnitChange = unit => {
    this.setState({ unit });
    this.props.onChange({ value: this.state.value, unit });
  }

  render() {
    const { describedBy, name } = this.props;
    const inputName = `${name}Value`;
    const dropdownName = `${name}Unit`;
    return (
      <div className="form-group">
        <div className="input-group">
          <input
            className="form-control"
            type="number"
            step="any"
            onChange={this.onValueChange}
            placeholder={this.props.placeholder}
            aria-describedby={describedBy}
            name={inputName}
            required={this.props.required}
          />
          <Dropdown
            title={this.props.defaultRequestSizeUnit}
            selectedKey={this.props.defaultRequestSizeUnit}
            name={dropdownName}
            className="btn-group"
            items={this.props.dropdownUnits}
            onChange={this.onUnitChange}
            required={this.props.required}
          />
        </div>
      </div>
    );
  }
}

export type RequestSizeInputProps = {
  placeholder?: string;
  name: string;
  onChange: Function;
  required?: boolean;
  dropdownUnits: any;
  defaultRequestSizeUnit: string;
  defaultRequestSizeValue: string;
  describedBy?: string;
};

==> openshift-enterprise-console-container-v4.2.4-201911050122.tar.gz: openshift-enterprise-console-container-v4.2.4-201911050122/frontend/public/components/utils/request-size-input.tsx <==
import * as React from 'react';
import { Dropdown } from '.';

export class RequestSizeInput extends React.Component<RequestSizeInputProps> {
  state = {
    unit: this.props.defaultRequestSizeUnit,
    value: this.props.defaultRequestSizeValue,
  }

  onValueChange: React.ReactEventHandler<HTMLInputElement> = event => {
    this.setState({ value: event.currentTarget.value });
    this.props.onChange({ value: event.currentTarget.value, unit: this.state.unit });
  };

  onUnitChange = unit => {
    this.setState({ unit });
    this.props.onChange({ value: this.state.value, unit });
  }

  render() {
    const { describedBy, name } = this.props;
    const inputName = `${name}Value`;
    const dropdownName = `${name}Unit`;
    return (
      <div className="form-group">
        <div className="pf-c-input-group">
          <input
            className="pf-c-form-control"
            type="number"
            step="any"
            onChange={this.onValueChange}
            placeholder={this.props.placeholder}
            aria-describedby={describedBy}
            name={inputName}
            required={this.props.required}
            value={this.props.defaultRequestSizeValue}
          />
          <Dropdown
            title={this.props.defaultRequestSizeUnit}
            selectedKey={this.props.defaultRequestSizeUnit}
            name={dropdownName}
            className="btn-group"
            items={this.props.dropdownUnits}
            onChange={this.onUnitChange}
            required={this.props.required}
          />
        </div>
      </div>
    );
  }
}

export type RequestSizeInputProps = {
  placeholder?: string;
  name: string;
  onChange: Function;
  required?: boolean;
  dropdownUnits: any;
  defaultRequestSizeUnit: string;
  defaultRequestSizeValue: string;
  describedBy?: string;
};
